# LLG

The main objective of this library is to solve the [LLG equation](https://en.wikipedia.org/wiki/Landau%E2%80%93Lifshitz%E2%80%93Gilbert_equation) by using the Heun schema. We also implemented a CLI in order to let you use `llg` from console. You can follow the instructions given on the [wiki](https://github.com/lufvelasquezgo/llg/wiki). Do not hesitate to write us if you have any suggestion/question.

- Free software: MIT license
- Documentation: https://github.com/lufvelasquezgo/llg/wiki
